==> appboxo_sdk-0.1.4.tar.gz: android/src/main/kotlin/com/appboxo/appboxo_sdk/AppboxoSdkPlugin.kt <==
package com.appboxo.appboxo_sdk

import android.app.Activity
import androidx.annotation.NonNull
import com.appboxo.js.params.CustomEvent
import com.appboxo.sdk.Appboxo
import com.appboxo.sdk.Config
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

class AppboxoSdkPlugin(private val activity: Activity) : MethodCallHandler, EventChannel.StreamHandler {
    private var events: EventChannel.EventSink? = null

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "setConfig" -> {
                val clientId = call.argument<String>("client_id")!!
                Appboxo.setConfig(Config.Builder()
                        .setClientId(clientId)
                        .build())
            }
            "openMiniApp" -> {
                val appId = call.argument<String>("app_id")!!
                val payload = call.argument<String>("payload")!!
                Appboxo.getMiniApp(appId, payload).open(activity)
            }

            "openMiniAppWithCustomEvents" -> {
                val appId = call.argument<String>("app_id")!!
                val payload = call.argument<String>("payload")!!
                Appboxo.getMiniApp(appId, payload)
                        .setCustomEventListener { _, miniApp, customEvent ->
                            events?.success(
                                    mapOf("appId" to miniApp.appId,
                                            "requestId" to customEvent.requestId,
                                            "type" to customEvent.type,
                                            "errorType" to customEvent.errorType,
                                            "payload" to customEvent.payload))
                        }
                        .open(activity)
            }

            "sendEvent" -> {
                try {
                    val map = call.argument<Map<String, *>>("custom_event")!!
                    val appId = map["appId"] as String

                    @Suppress("UNCHECKED_CAST")
                    val customEvent = CustomEvent(requestId = map["requestId"] as? String,
                            type = map["type"] as String,
                            errorType = map["errorType"] as? String,
                            payload = map["payload"] as Map<String, Any>
                    )
                    Appboxo.getMiniApp(appId)?.sendEvent(customEvent)
                } catch (e: Exception) {
                    print(e)
                }
            }
        }
    }

    override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
        this.events = events
    }

    override fun onCancel(arguments: Any?) {
        events = null
    }

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            Appboxo.init(registrar.activity().application)
            val channel = MethodChannel(registrar.messenger(), "appboxo_sdk")
            val eventChannel = EventChannel(registrar.messenger(), "appboxo_sdk_custom_events")
            val plugin = AppboxoSdkPlugin(registrar.activity())
            channel.setMethodCallHandler(plugin)
            eventChannel.setStreamHandler(plugin)
        }
    }
}

==> appboxo_sdk-0.1.5.tar.gz: android/src/main/kotlin/com/appboxo/appboxo_sdk/AppboxoSdkPlugin.kt <==
package com.appboxo.appboxo_sdk

import android.app.Activity
import androidx.annotation.NonNull
import com.appboxo.js.params.CustomEvent
import com.appboxo.sdk.Appboxo
import com.appboxo.sdk.Config
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

class AppboxoSdkPlugin(private val activity: Activity) : MethodCallHandler, EventChannel.StreamHandler {
    private var events: EventChannel.EventSink? = null

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "setConfig" -> {
                val clientId = call.argument<String>("client_id")!!
                Appboxo.setConfig(Config.Builder()
                        .setClientId(clientId)
                        .build())
            }
            "openMiniApp" -> {
                val appId = call.argument<String>("app_id")!!
                val payload = call.argument<String>("payload") ?: ""
                val data = call.argument<String>("data") ?: ""
                Appboxo.getMiniApp(appId, payload, data)
                        .setCustomEventListener { _, miniApp, customEvent ->
                            events?.success(
                                    mapOf("appId" to miniApp.appId,
                                            "requestId" to customEvent.requestId,
                                            "type" to customEvent.type,
                                            "errorType" to customEvent.errorType,
                                            "payload" to customEvent.payload))
                        }
                        .open(activity)
            }

            "sendEvent" -> {
                try {
                    val map = call.argument<Map<String, *>>("custom_event")!!
                    val appId = map["appId"] as String

                    @Suppress("UNCHECKED_CAST")
                    val customEvent = CustomEvent(requestId = map["requestId"] as? String,
                            type = map["type"] as String,
                            errorType = map["errorType"] as? String,
                            payload = map["payload"] as Map<String, Any>
                    )
                    Appboxo.getMiniApp(appId)?.sendEvent(customEvent)
                } catch (e: Exception) {
                    print(e)
                }
            }
        }
    }

    override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
        this.events = events
    }

    override fun onCancel(arguments: Any?) {
        events = null
    }

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            Appboxo.init(registrar.activity().application)
            val channel = MethodChannel(registrar.messenger(), "appboxo_sdk")
            val eventChannel = EventChannel(registrar.messenger(), "appboxo_sdk_custom_events")
            val plugin = AppboxoSdkPlugin(registrar.activity())
            channel.setMethodCallHandler(plugin)
            eventChannel.setStreamHandler(plugin)
        }
    }
}
